#encoding=utf-8
# Данный пример поочерёдно включает и выключает каналы модуля.      # * Строки со звёздочкой являются необязательными.
                                                                    #
from pyiArduinoI2Crelay import *                                 #   Подключаем библиотеку для работы с реле и силовыми ключами.
from time import sleep                        # Подключаем метод sleep библиотеки time
relay = pyiArduinoI2Crelay(0x09);                          #   Создаём объект relay для работы с функциями и методами библиотеки Py_iarduino_I2C_Relay, указывая адрес модуля на шине I2C.
                                                                    #   Если объявить объект без указания адреса (iarduino_I2C_Relay relay;), то адрес будет найден автоматически.
relay.digitalWrite(ALL_CHANNEL,LOW);                              # * Выключаем все каналы модуля.
while True:                                                       #   Входим в бесконечный цикл
#Включаем и выключаем каналы модуля:                              #
  relay.digitalWrite(1,HIGH)                    # Включаем 1 канал
  relay.digitalWrite(4,LOW)                         #   и выключаем 4.
  sleep(.5)                                                       #   Ждём   500 мс.
  relay.digitalWrite(2,HIGH)                    # Включаем 2 канал
  relay.digitalWrite(1,LOW)                         #   и выключаем 1.
  sleep(.5)                                                       #   Ждём   500 мс.
  relay.digitalWrite(3,HIGH)                    # Включаем 3 канал
  relay.digitalWrite(2,LOW)                         #   и выключаем 2.
  sleep(.5)                                                     #   Ждём   500 мс.
  relay.digitalWrite(4,HIGH)                    # Включаем 4 канал
  relay.digitalWrite(3,LOW)                         #   и выключаем 3.
  sleep(.5)                                                       #   Ждём   500 мс.  



cdef extern from "iarduino_I2C_Relay.cpp":
	pass

cdef extern from "iarduino_I2C_Relay.h":
	cdef cppclass iarduino_I2C_Relay:
		iarduino_I2C_Relay() except +
		iarduino_I2C_Relay(unsigned char) except +
		bint begin()
		bint changeAddress(unsigned char)
		bint reset()
		unsigned char getAddress()
		unsigned char getVersion()
		unsigned char getModel()
		void digitalWrite(unsigned char, unsigned char)
		unsigned char digitalRead(unsigned char)
		void analogWrite(unsigned char, unsigned short)
		unsigned short analogRead(unsigned char)
		void analogAveraging(unsigned char)
		void freqPWM(unsigned short)
		void currentWrite(unsigned char, float)
		void currentWrite(unsigned char, float, unsigned char&)
		float currentRead(unsigned char)
		void setCurrentProtection(unsigned char, float, unsigned char)
		bint getCurrentProtection(unsigned char)
		void delCurrentProtection(unsigned char)
		void resCurrentProtection(unsigned char) 



#encoding=utf-8
# Данный пример меняет адрес модуля на указанный в переменной «i».      		#  	
from pyiArduinoI2Crelay import *                                     		#	Подключаем библиотеку для работы с реле и силовыми ключами.
																				#
i = 0x09                                                               			#	Назначаемый модулю новый адрес (0x07 < адрес < 0x7F).
																				#
choices = {																		#	Структура для сравнения методом get()
	DEF_MODEL_2RM: "электромеханическим реле на 2-канала",						#
	DEF_MODEL_4RT: "твердотельным реле на 4-канала",							#
	DEF_MODEL_4NC: "силовым ключом на 4 N-канала с измерением тока",			#
	DEF_MODEL_4PC: "силовым ключом на 4 P-канала с измерением тока",			#
	DEF_MODEL_4NP: "силовым ключом на 4 N-канала до 10A",						#
	DEF_MODEL_4PP: "силовым ключом на 4 P-канала до 10A"						#
}																				#
																				#
relay = pyiArduinoI2Crelay()													#	Объявляем объект relay для работы с функциями и методами библиотеки iarduino_I2C_Relay.
print("На шине I2C ", end='')													#
if relay.begin():																#	Инициируем работу с модулем реле или силовыми ключами.
	address = relay.getAddress()												#	Если при объявлении объекта указать адрес, например, relay(0xBB), то пример будет работать с тем модулем, адрес которого был указан.
	model = relay.getModel()													#
	model = choices.get(model, "неизвестным силовым ключом или реле")			# 	Cравниваем модель модуля с константами, если ни одна не совпала - выводим строку по усолчанию
	print("найден модуль с адресом %s, который является %s" % (address, model))	#	Выводим текущий адрес модуля.
	if relay.changeAddress(i):													#	Меняем адрес модуля на указанный в переменной i.
		print("Адрес модуля изменён на %s" % (relay.getAddress()))				#	Выводим текущий адрес модуля.
	else:																		#	Если метод relay.changeAddress() вернул false, значит библиотеке не удалось сменить адрес модуля.
		print("Адрес модуля изменить не удалось!")								#
else:																			#	Если метод relay.begin() вернул false, значит библиотеке не удалось найти модуль реле или силовых ключей.
	print("нет ни силовых ключей, ни реле!")									#



#encoding=utf-8
#Данный пример считывает текущее состояние каналов модуля.
from pyiArduinoI2Crelay import *										# Подключаем библиотеку (модуль) для работы с реле
relay = pyiArduinoI2Crelay()                                         # Объявляем объект relay для работы с функциями и методами библиотеки iarduino_I2C_Relay, указывая адрес модуля на шине I2C.
																		# Если объявить объект без указания адреса (iarduino_I2C_Relay relay;), то адрес будет найден автоматически.
#	Включаем и выключаем каналы модуля: 								#
relay.digitalWrite(1, LOW);        	                             		# Отключаем 1 канал.
relay.digitalWrite(2,HIGH);         	                            	# Включаем  2 канал.
relay.digitalWrite(3, LOW);             	                        	# Отключаем 3 канал.
relay.digitalWrite(4,HIGH);                 	                    	# Включаем  4 канал.
#  Проверяем состояние каналов модуля в цикле:							#											
for i in range(4):														# Прозодим по всем каналам модуля.
	print("Канал № %s" % (i), end='')									# Выводим номер очередного канала.
	if relay.digitalRead(i):											# Если функция digitalRead() вернула True
		print(" включен ", end='')										# значит канал включён.
	else:																# Если функция digitalRead() вернула False 
		print(" отключен\t", end='')									# значит канал отключён.
print("--------")	
#  ПРИМЕЧАНИЕ: состояние всех каналов можно получить одним байтом: 
#  uint8_t j = relay.digitalRead(ALL_CHANNEL);                        
# 4 младших бита переменной «j» соответствуют состояниям 4 каналов модуля.																	



# distutils: language = c++
#encoding = utf-8
DEF_CHIP_ID	=	0x3C
DEF_MODEL_2RM	=	0x0A
DEF_MODEL_4RT	=	0x0B
DEF_MODEL_4NC	=	0x0C
DEF_MODEL_4PC	=	0x0D
DEF_MODEL_4NP	=	0x0E
DEF_MODEL_4PP	=	0x0F
#	Адреса регистров модулей:																	
REG_FLAGS_0 =0x00
REG_BITS_0 = 0x01
REG_FLAGS_1 =	0x02
REG_BITS_1 = 0x03
REG_MODEL	=	0x04
REG_VERSION	=	0x05
REG_ADDRESS	=	0x06
REG_CHIP_ID	=	0x07
REG_FREQUENCY_L	=	0x08
REG_FREQUENCY_H	=	0x09
REG_AVERAGING	=	0x0A
REG_SHUNT	=	0x0B
REG_FLG	=	0x10
REG_BIT	=	0x11
REG_DIGITAL_ALL	=	0x12																		
REG_DIGITAL_ONE	=	0x13																		
REG_PWM	=	0x14
REG_ADC	=	0x1C
REG_CURRENT	=	0x24
REG_LIMIT	=	0x2C
FLG_A_OFF	=	0																							
FLG_A_MAX	=	4																							
BIT_A_OFF	=	0																							
BIT_A_MAX	=	4																							
BIT_WRITE_L	=	0																						
BIT_WRITE_H	=	4																						
ALL_CHANNEL = 0xFF
CURRENT_LIMIT = 0xFF
CURRENT_DISABLE = 0x00
HIGH = 0x01
LOW = 0x00

from iarduino_I2C_Relay cimport iarduino_I2C_Relay

cdef class pyiArduinoI2Crelay:
	cdef iarduino_I2C_Relay c_relay

	def __cinit__(self, address=None):
		if address is not None:
			self.c_relay = iarduino_I2C_Relay(address)
			self.c_relay.begin()
		else:
			self.c_relay = iarduino_I2C_Relay()
			self.c_relay.begin()

	def begin(self):
		return self.c_relay.begin()

	def changeAddress(self, unsigned char newAddr):
		return self.c_relay.changeAddress(newAddr)

	def reset(self):
		return self.c_relay.reset()

	def getAddress(self):
		return self.c_relay.getAddress()

	def getVersion(self):
		return self.c_relay.getVersion()

	def getModel(self):
		return self.c_relay.getModel()

	def digitalWrite(self, unsigned char channel, unsigned char level):
		self.c_relay.digitalWrite(channel, level)

	def digitalRead(self, unsigned char channel):
		return self.c_relay.digitalRead(channel)
	
	def analogWrite(self, unsigned char channel, unsigned short level):
		self.c_relay.analogWrite(channel, level)

	def analogRead(self, unsigned char channel):
		return self.c_relay.analogRead(channel)

	def analogAveraging(self, unsigned char coefficient):
		self.c_relay.analogAveraging(coefficient)

	def freqPWM(self, unsigned short frequency):
		self.c_relay.freqPWM(frequency)

	def currentWrite(self, unsigned char channel, float current):
		self.c_relay.currentWrite(channel, current)

	def currentWrite(self, unsigned char channel, float current,unsigned char& Rsh):
		self.c_relay.currentWrite(channel, current, Rsh)

	def currentRead(self,unsigned char channel):
		return self.c_relay.currentRead(channel)

	def setCurrentProtection(self, unsigned char channel, float current, unsigned char rtype):
		self.c_relay.setCurrentProtection(channel, current, rtype)

	def getCurrentProtection(self, unsigned char channel):
		return self.c_relay.getCurrentProtection(channel)

	def delCurrentProtection(self, unsigned char channel):
		self.c_relay.delCurrentProtection(channel)

	def resCurrentProtection(self, unsigned char channel):
		self.c_relay.resCurrentProtection(channel)



#encoding=utf-8
# Данный пример демонстрирует программную перезагрузку модуля.	#
from pyiArduinoI2Crelay import *								#	Подключаем библиотеку для работы с реле и силовыми ключами.
from time import sleep											#	Подключаем метод sleep библиотеки time.
																#	
relay = pyiArduinoI2Crelay(0x09)								#	Объявляем объект relay для работы с функциями и методами библиотеки iarduino_I2C_Relay, указывая адрес модуля на шине I2C.
while True:														#	Входим в бесконечный цикл
	relay.digitalWrite(ALL_CHANNEL, HIGH)						#	Включаем все каналы модуля.
	sleep(2)													#	Ждём две секунды.
	relay.reset()												#	Перезагружаем модуль: после перезагрузки все регистры сбросятся в значения по умолчанию, все каналы будут отключены.
	sleep(2)													#	Ждём две секунды.



#encoding=utf-8
#Данный пример определяет тип модуля реле или силового ключа подключённого к шине I2C.
from pyiArduinoI2Crelay import *										# Подключаем библиотеку для работы с реле
relay = pyiArduinoI2Crelay()                                         # Объявляем объект relay для работы с функциями и методами модуля Py_iarduino_I2C_Relay.
                                                                        # Если при объявлении объекта указать адрес, например, relay(0xBB), то пример будет работать с тем модулем, адрес которого был указан.
print("На шине I2C", end=' ')											# 
if relay.begin():														# Инициируем работу с модулем реле или силовыми ключами.
	address = relay.getAddress()										# Записываем адресс
	model = relay.getModel()											# Записываем модель
	version = relay.getVersion()										# Записываем версию
	if model == DEF_MODEL_2RM:											# Сравниваем с константами
		model == "электромеханическим реле на 2-канала"					# и записываем в ту же переменную
	elif model == DEF_MODEL_4RT:										#
 		model == "твердотельным реле на 4-канала"						#
	elif model == DEF_MODEL_4NC:										#
 		model == "силовым ключом на 4 N-канала с измерением тока"		#
	elif model == DEF_MODEL_4PC:										#
 		model == "силовым ключом на 4 P-канала с измерением тока"		#
	elif model == DEF_MODEL_4NP:										#
 		model == "силовым ключом на 4 n-канала до 10a"					#
	elif model == DEF_MODEL_4PP:										#
 		model == "силовым ключом на 4 P-канала до 10A"					#
	else:																#
 		model == "неизвестным силовым ключом или реле"					#
	#выводим текст в консоль.
	print("найден модуль с адресом %s, версия прошивки модуля: %s.0." % (hex(address), version))                                                                  # Инициируем работу с модулем реле или силовыми ключами.
else: 
	print("нет ни силовых ключей, ни реле!")  # Если метод relay.begin() вернул false, значит библиотеке не удалось найти модуль реле или силовых ключей.



from distutils.core import setup
from distutils.extension import Extension
#from Cython.Build import cythonize
#from Cython.Distutils import build_ext

def readme():
	with open('README.md') as readme:
		return readme.read()

setup(name='pyiArduinoI2Crelay',
	version='1.6.5',
	description='iarduino.ru module for Raspberry Pi',
	long_description=readme(),
	classifiers=[
		'Programming Language :: Python :: 3',
	],
	url='http://github.com/tremaru/pyiArduinoI2Crelay',
	author='iarduino.ru',
	author_email='shop@iarduino.ru',
	license='MIT',
	package=['pyiArduinoI2Crelay'],
	ext_modules = [Extension(
		name="pyiArduinoI2Crelay",
		sources=["pyiArduinoI2Crelay/pyiArduinoI2Crelay.cpp"])],
	include_package_data=True,
        zip_safe=False,
	python_requires='>=3',
)
